do_dart library

DO-Dart is an implementation of the DigitalOcean api in Dart. It aims to enable developers such as me to interact with DigitalOcean API

Classes

Account
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
AccountService
Action
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Actions
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
ActionService
Backup
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Backups
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
BlockStorage
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
BlockStorageActionService
Block Storage actions are commands that can be given to a DigitalOcean Block Storage volume
BlockStorageCreateRequest
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
BlockStorages
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
BlockStorageService
Certificate
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
CertificateCreateRequest
Certificates
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
CertificateService
Client
Destination
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Domain
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
DomainRecord
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
DomainRecordCreateRequest
DomainRecords
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
DomainRecordService
DomainRecordUpdateRequest
Domains
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
DomainService
Droplet
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
DropletActionService
DropletCreateManyRequest
DropletCreateRequest
Droplets
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
DropletService
Endpoint
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Endpoints
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
EndpointService
Firewall
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
FirewallCreateRequest
Firewalls
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
FirewallService
FirewallUpdateRequest
FloatingIP
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
FloatingIPActionService
FloatingIPs
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
FloatingIPService
Image
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
ImageActionService
Images
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
ImageService
InboundRule
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Kernel
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Kernels
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Kubernetes
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
ListOptions
LoadBalancer
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Meta
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
OutboundRule
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Pages
Project
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
ProjectResource
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
ProjectResources
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
ProjectResourceService
Projects
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
ProjectService
Purpose
Region
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Regions
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
RegionService
Size
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Sizes
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
SizeService
Snapshot
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Snapshots
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
SnapshotService
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
SSHKey
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
SSHKeys
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
SSHKeyService
Tag
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
Urn
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.

Enums

Environment

Exceptions / Errors

DigitalOceanException