type property

String type
getter/setter pair

This is the type of action that the object represents. For example, this could be "transfer" to represent the state of an image transfer action.

Implementation

String type;