BlockStorageActionService class
Block Storage actions are commands that can be given to a DigitalOcean Block Storage volume
Constructors
- BlockStorageActionService(Client client)
Properties
Methods
-
attach(
String volumeId, int dropletId, {String? region}) → Future< Action> - Attach a Block Storage volume to a Droplet
-
detach(
String volumeId, int dropletId, {String? region}) → Future< Action> - Remove a Block Storage volume from a Droplet
-
getAction(
String volumeId, String actionId) → Future< Action> -
Retrieve an existing volume action
actionId: The id of the action -
list(
String volumeId) → Future< Actions> - List all actions for a volume
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resize(
String volumeId, int sizeGigabytes, {String? region}) → Future< Action> - Resize a volume
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited