CertificateCreateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CertificateCreateRequest(String name, String type, {String? private_key, String? leaf_certificate, String? certificate_chain, List<String>? dns_names})
CertificateCreateRequest.fromJson(Map<String, dynamic> json)
factory

Properties

certificate_chain String?
getter/setter pair
dns_names List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
leaf_certificate String?
getter/setter pair
name String
getter/setter pair
private_key String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited