DomainRecordUpdateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

DomainRecordUpdateRequest({String? type, String? name, String? data, int? priority, int? port, int? ttl, int? weight, int? flags, String? tag})
DomainRecordUpdateRequest.fromJson(Map<String, dynamic> json)
factory

Properties

data String?
getter/setter pair
flags int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
port int?
getter/setter pair
priority int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
getter/setter pair
ttl int?
getter/setter pair
type String?
getter/setter pair
weight int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited