DomainRecords class

An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DomainRecords(List<DomainRecord> drs, Links links, Meta meta)
DomainRecords.fromJson(Map<String, dynamic> json)
factory

Properties

drs List<DomainRecord>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pairinherited
meta Meta?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCount() int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited