FloatingIP class

An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FloatingIP(String ip, Region region, Droplet droplet)
FloatingIP.fromJson(Map<String, dynamic> json)
factory

Properties

droplet Droplet
The Droplet that the Floating IP has been assigned to. When you query a Floating IP, if it is assigned to a Droplet, the entire Droplet object will be returned. If it is not assigned, the value will be null.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ip String
The public IP address of the Floating IP. It also serves as its identifier.
getter/setter pair
region Region
The region that the Floating IP is reserved to. When you query a Floating IP, the entire region object will be returned.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited