FloatingIPActionService class

Constructors

FloatingIPActionService(Client client)

Properties

basePath String
getter/setter pairinherited
client Client
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assign(String floatingIpAddr, int dropletId) Future<Action>
get(String floatingIpAddr, String actionId) Future<Action>
list(String floatingIpAddr, [ListOptions? ops]) Future<Actions>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unassign(String floatingIpAddr) Future<Action>

Operators

operator ==(Object other) bool
The equality operator.
inherited