ImageActionService class

Constructors

ImageActionService(Client client)

Properties

basePath String
getter/setter pairinherited
client Client
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(String imageId) Future<Action>
Convert an image to a snapshot
get(String imageId, String imageActionId) Future<Action>
Retrieve an existing action
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transfer(String imageId, String region) Future<Action>
List all snapshots

Operators

operator ==(Object other) bool
The equality operator.
inherited