ProjectResourceService class

Constructors

ProjectResourceService(Client client)

Properties

basePath String
getter/setter pairinherited
client Client
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assignDefaultProjectResources([ListOptions? ops]) Future<ProjectResources>
Assigns Default Project Resources
assignResource(String projectId, List<Urn> urns) Future<ProjectResource>
Assigns Project Resources
listDefaultProjectResources() Future<ProjectResources>
Lists Default Project Resources
listResources(String projectId) Future<ProjectResources>
Lists Project Resources
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited