Purpose class

Constructors

Purpose()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

ai String
final
educational String
final
iot String
final
mobileApp String
final
ops String
final
service String
final
trying String
final
web String
final
webApp String
final