Action class
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
Properties
- completed_at ↔ String?
-
A time value given in ISO8601 combined date and time format that represents when the action was completed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
A unique numeric ID that can be used to identify and reference an action.
getter/setter pair
- region ↔ Region
-
A full region object containing information about the region where the action occurred.
getter/setter pair
- region_slug ↔ String?
-
A slug representing the region where the action occurred.
getter/setter pair
- resource_id ↔ int?
-
A unique identifier for the resource that the action is associated with.
getter/setter pair
- resource_type ↔ String
-
The type of resource that the action is associated with.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- started_at ↔ String
-
A time value given in ISO8601 combined date and time format that represents when the action was initiated.
getter/setter pair
- status ↔ String
-
The current status of the action. This can be "in-progress", "completed", or "errored".
getter/setter pair
- type ↔ String
-
This is the type of action that the object represents. For example, this could be "transfer" to represent the state of an image transfer action.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited