type property
This is the type of action that the object represents. For example, this could be "transfer" to represent the state of an image transfer action.
Implementation
String type;
This is the type of action that the object represents. For example, this could be "transfer" to represent the state of an image transfer action.
String type;