DomainRecords class
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
DomainRecords(List<
DomainRecord> drs, Links links, Meta meta) -
DomainRecords.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
getCount(
) → int -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited