Region class
An annotation for the code generator to know that this class needs the JSON serialization logic to be generated.
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- available ↔ bool
-
This is a boolean value that represents whether new Droplets can be created in this region.
getter/setter pair
- features ↔ List
-
This attribute is set to an array which contains features available in this region
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
The display name of the region. This will be a full name that is used in the control panel and other interfaces.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sizes
↔ List<
String> -
This attribute is set to an array which contains the identifying slugs for the sizes available in this region.
getter/setter pair
- slug ↔ String
-
A human-readable string that is used as a unique identifier for each region.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited